Bloom Filter Trie: BFT_kmer Struct Reference

Bloom Filter Trie

- Main Page
- Data Structures
- Files

- Data Structures
- Data Structure Index
- Data Fields

Data Fields
BFT_kmer Struct Reference

K-mer stored in a BFT_Root. More...

## Data Fields
char * | kmer
| ASCII null-terminated k-mer. More...
uint8_t * | kmer_comp
| 2 bits encoded form of BFT_kmer::kmer. More...
resultPresence * | res
| Contains information about the location of BFT_kmer::kmer in a BFT_Root. More...

## Detailed Description

K-mer stored in a BFT_Root.

A BFT_kmer contains the k-mer in its ASCII form and 2 bits encoded form, as well as information about its location in a BFT_Root.

## Field Documentation

char* BFT_kmer::kmer

ASCII null-terminated k-mer.

uint8_t* BFT_kmer::kmer_comp

2 bits encoded form of BFT_kmer::kmer.

resultPresence* BFT_kmer::res

Contains information about the location of BFT_kmer::kmer in a BFT_Root.

The documentation for this struct was generated from the following file:

- include/Node.h